@@ -38,6 +38,12 @@ const Window = imports.window;
 const World = imports.world;
 const SearchProvider = imports.searchProvider;
 
+function initEnvironment() {
+    window.getApp = function() {
+        return Gio.Application.get_default();
+    };
+}
+
 const Application = new Lang.Class({
     Name: 'WeatherApplication',
     Extends: Gtk.Application,
@@ -70,10 +76,10 @@ const Application = new Lang.Class({
         return true;
     },
 
-    vfunc_dbus_unregister: function(connection) {
+    vfunc_dbus_unregister: function(connection, path) {
         this._searchProvider.unexport(connection);
 
-        this.parent(connection);
+        this.parent(connection, path);
     },
 
     vfunc_startup: function() {
@@ -88,6 +94,15 @@ const Application = new Lang.Class({
         this.world = GWeather.Location.get_world();
         this.model = new World.WorldModel(this.world);
 
+        this.model.connect('notify::loading', Lang.bind(this, function() {
+            if (this.model.loading)
+                this.mark_busy();
+            else
+                this.unmark_busy();
+        }));
+        if (this.model.loading)
+            this.mark_busy();
+
         Util.initActions(this,
                          [{ name: 'quit',
                             activate: this._onQuit }]);
@@ -105,7 +120,16 @@ const Application = new Lang.Class({
     },
 
     vfunc_activate: function() {
-        (new Window.MainWindow({ application: this })).show();
+        let win = new Window.MainWindow({ application: this });
+
+        if (this.model.loading) {
+            let id = this.model.connect('notify::loading', function(model) {
+                model.disconnect(id);
+                win.show();
+            });
+        } else {
+            win.show();
+        }
     },
 
     vfunc_shutdown: function() {
@@ -116,5 +140,7 @@ const Application = new Lang.Class({
 });
 
 function main(argv) {
+    initEnvironment();
+
     return (new Application()).run(argv);
 }
